from wakeonlan import wol
import base64
import paramiko
import socket
import sys

__all__ = ["SERVER_DOWN", "SERVER_UP", "SERVER_UP_NOT_RESPONDING", "ServerPower"]

SERVER_DOWN = 1
SERVER_UP = 2
SERVER_UP_NOT_RESPONDING = 3

class ServerPower(object):
    def __init__(self, **kwargs):
        self.server_hostname = kwargs["server_hostname"]
        self.server_mac = kwargs["server_mac"]
        self.ssh_username = kwargs["ssh_username"]

        self.server_port = kwargs.get("server_port", 22)
        self.broadcast_ip = kwargs.get("broadcast_ip", "255.255.255.255")
        self.socket_timeout = kwargs.get("socket_timeout", 0.1)
        self.wol_port = kwargs.get("wol_port", 9)

    def is_alive(self):
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.settimeout(self.socket_timeout)
        try:
            s.connect((self.server_hostname, self.server_port))
        except socket.error, e:
            if e.errno == 61: # connection refused
                return SERVER_UP_NOT_RESPONDING
            elif e.message == "timed out": # socket timeout
                return SERVER_DOWN
            elif e.errno == 8: # invalid hostname
                raise e
            elif e.errno == 51: # network is unreachable
                return SERVER_DOWN
            elif e.errno == 64: # host is down
                return SERVER_DOWN
            else:
                print "Message:", e.message
                print "Error:", e.errno, e.strerror
                raise e
        return SERVER_UP

    def wake_up(self):
        for _ in range(0,3):
            wol.send_magic_packet(self.server_mac, port=self.wol_port)

    def shutdown(self):
        client = paramiko.SSHClient()
        client.load_system_host_keys()
        client.connect(self.server_hostname, username=self.ssh_username)
        _, stdout, stderr = client.exec_command("sudo shutdown")
        stdout = stdout.read()
        stderr = stderr.read()
        client.close()
        return (stdout, stderr)


def main():
    sp = ServerPower(server_hostname="192.168.1.3", server_mac="28:92:4a:2b:03:c9", ssh_username="powermanagement", broadcast_ip="192.168.1.255")
    print sp.is_alive()
    print sp.wake_up()
    return 0

if __name__ == '__main__':
    sys.exit(main())



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='manage_server_power',
    version='0.0.3',
    description='Small library for shutting down and starting up local server',
    long_description=long_description,
    url='https://github.com/ojarva/python-manage-server-power',
    author='Olli Jarva',
    author_email='olli@jarva.fi',
    license='BSD',

    classifiers=[
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: BSD License',

        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
    keywords='wol wake-on-lan',
    packages=["manage_server_power"],
    test_suite="tests",
    install_requires=['wakeonlan', 'paramiko'],

    extras_require = {
        'dev': ['twine', 'wheel'],
    },
)
